@@ -7,7 +7,7 @@ use File::Spec;
 use File::HomeDir;
 
 # ABSTRACT: A framework for RESTful processing systems.
-our $VERSION = '1.10'; # VERSION
+our $VERSION = '1.11'; # VERSION
 
 
 sub _testing
@@ -58,6 +58,39 @@ sub _dist_dir
     }
 }
 
+sub _generate_port
+{
+  require IO::Socket::INET;
+  # this code is duplicated in Test::Clustericious::Command,
+  # don't want to move it just FYI
+  IO::Socket::INET->new(Listen => 5, LocalAddr => "127.0.0.1")->sockport
+}
+
+sub _default_url
+{
+  my(undef, $app_name) = @_;
+  require File::HomeDir;
+  require Path::Class::File;
+  require JSON::PP;
+  require Mojo::URL;
+  my $file = Path::Class::File->new(File::HomeDir->my_dist_data("Clustericious", { create => 1 } ), 'default_ports.json');
+
+  $app_name =~ s{::}{-};
+  
+  my $data = -f $file ? JSON::PP::decode_json(scalar $file->slurp) : {};
+  
+  $data->{$app_name} // do {
+    my $url = Mojo::URL->new('http://127.0.0.1');
+    $url->port(__PACKAGE__->_generate_port);
+    $url = $url->to_string;
+
+    $data->{$app_name} = $url;
+    $file->spew(JSON::PP::encode_json($data));
+
+    $url;
+  };
+}
+
 # Note sub _config_uncache also gets placed
 # in this package, but it is defined in
 # Clustericious::Config.
@@ -76,7 +109,7 @@ Clustericious - A framework for RESTful processing systems.
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 SYNOPSIS
 
@@ -93,7 +126,8 @@ Basic application layout:
  sub startup
  {
    my($self) = @_;
-   # just like Mojolicious startup()
+   $self->SUPER::startup;
+   # app startup
  }
  
  package MyApp::Routes;
