@@ -7,8 +7,7 @@ use Sub::Identify 0.05 qw( get_code_location get_code_info );
 use Mojo::Base qw( Clustericious::Command );
 
 # ABSTRACT: Clustericious command to start a Clustericious application
-our $VERSION = '1.28_01'; # TRIAL VERSION 
-$VERSION = eval $VERSION;
+our $VERSION = '1.11'; # VERSION 
 
 has description => <<EOT;
 Determine the location of method or helper.
@@ -74,7 +73,7 @@ Clustericious::Command::which - Clustericious command to start a Clustericious a
 
 =head1 VERSION
 
-version 1.28_01
+version 1.11
 
 =head1 AUTHOR
 
@@ -86,8 +85,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
