@@ -11,7 +11,7 @@ use JSON::MaybeXS qw( encode_json );
 use Clustericious::Config;
 
 # ABSTRACT: Helpers for clustericious config files.
-our $VERSION = '1.10'; # VERSION
+our $VERSION = '1.11'; # VERSION
 
 
 our @mergeStack;
@@ -177,7 +177,7 @@ Clustericious::Config::Helpers - Helpers for clustericious config files.
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 SYNOPSIS
 
@@ -191,46 +191,68 @@ using L<Clustericious::Config>.
 
 =head1 FUNCTIONS
 
-=head2 extends_config $config_name, %arguments
+=head2 extends_config 
+
+ % extends_config $config_name, %arguments
 
 Extend the config using another config file.
 
 =head2 get_password
 
+ <%= get_password %>
+
 Prompt for a password.  This will prompt the user the first time it is
 encountered for a password.
 
-=head2 home( [ $user ] )
+=head2 home
+
+ <%= home %>
+ <%= home $user %>
 
 Return the given users' home directory, or if no user is
 specified return the calling user's home directory.
 
-=head2 file( @list )
+=head2 file
+
+ <%= file @list %>
 
 The C<file> shortcut from Path::Class, if it is installed.
 
-=head2 dir( @list )
+=head2 dir
+
+ <%= dir @list %>
 
 The C<dir> shortcut from Path::Class, if it is installed.
 
 =head2 hostname
 
+ <%= hostname %>
+
 The system hostname (uses L<Sys::Hostname>)
 
 =head2 hostname_full
 
+ <%= hostname_full %>
+
 The system hostname in full, including the domain, if
 it can be determined (uses L<Sys::Hostname>).
 
-=head2 json $ref
+=head2 json
+
+ <%= json $ref %>
 
 Encode the given hash or list reference.
 
-=head2 yaml $ref
+=head2 yaml
+
+ <%= yaml $ref %>
 
 Encode the given hash or list reference.
 
-=head2 address( [ $interface ] )
+=head2 address
+
+ <%= address %>
+ <%= address $interface %>
 
 Returns a list of IP addresses.  Requires L<Sys::HostAddr> to be installed.
 C<$interfaces>, if specified may be either a string or regular expression.
@@ -243,11 +265,15 @@ Only returns IPv4 addresses.
 
 =head2 public_address
 
+ <%= public_address %>
+
 Returns the public IPv4 address.  May not be an address on your host, if you
 are behind a firewall.  Requires L<Sys::HostAddr> to be installed.
 
 =head2 interface
 
+ <%= join ' ', interfaces %>
+
 Returns a list of network interfaces.  Requires L<Sys::HostAddr> to be installed.
 
 By default does not return loop back interfaces.
