@@ -4,16 +4,23 @@ use strict;
 use warnings;
 use Clustericious::Config;
 use Clustericious::Log;
+use Carp qw( carp );
 use base 'Mojolicious::Controller';
 
 # ABSTRACT: Clustericious controller base class
-our $VERSION = '1.10'; # VERSION
+our $VERSION = '1.11'; # VERSION
 
 
 sub url_for {
     my $c = shift;
 
-    # link_to calls url_for on a Mojo::URL which for some reason
+    # NOTE: the only place it looks like we need to use this bizzarely 
+    # customized url_for is in Restmd.  If we can confirm/deny that we
+    # do/don't need it there, then we can probably remove this special case
+    # NOTE2: also used in the function below.
+
+    # Note: This dos not seem to be the case anymore:
+    # Original Comment: link_to calls url_for on a Mojo::URL which for some reason
     # causes /a/b?c=d to not work properly (? is escaped)
     return $_[0] if @_==1 && ref($_[0]) eq "Mojo::URL";
 
@@ -52,8 +59,17 @@ sub redirect_to {
 }
 
 
-sub render_text { shift->render( text => @_ ) };
-sub render_json { shift->render( json => @_ ) };
+sub render_text
+{
+  carp "Clustericious::Controller#render_text is deprecated";
+  shift->render( text => @_ );
+}
+
+sub render_json
+{
+  carp "Clustericious::Controller#render_json is deprecated";
+  shift->render( json => @_ );
+}
 
 1;
 
@@ -69,7 +85,7 @@ Clustericious::Controller - Clustericious controller base class
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 SYNOPSIS
 
@@ -85,7 +101,7 @@ L<Mojolicious::Controller>
 
 =head1 METHODS
 
-=head2 $c-E<gt>url_for
+=head2 url_for
 
 Clustericious version of this method usually provided by Mojolicious.
 
@@ -100,13 +116,21 @@ It does this by explicitly using the url_base from the
 Clustericious config file for the app as the base for
 the location header.
 
-=head2 $c-E<gt>render_text
+=head2 render_text
+
+ $c->render_text($text);
+
+B<DEPRECATED>.
 
 Previous versions of Mojolicious included this
 method, and it was added here to ease the transition.  This method should be considered
 deprecated and may be removed in the future.
 
-=head2 $c-E<gt>render_json
+=head2 render_json
+
+ $c->render_json
+
+B<DEPRECATED>.
 
 Previous versions of Mojolicious included this
 method, and it was added here to ease the transition.  This method should be considered
