@@ -6,10 +6,10 @@ use Mojo::Base 'Clustericious::App';
 use Clustericious::RouteBuilder qw/Clustericious::HelloWorld/;
 
 # ABSTRACT: Clustericious hello world application
-our $VERSION = '1.10'; # VERSION
+our $VERSION = '1.11'; # VERSION
 
 
-get '/' => sub { shift->render_text('Hello, world') } => 'index';
+get '/' => sub { shift->render(text => 'Hello, world') } => 'index';
 
 get '/modules' => sub {
   my %copy = %INC;
@@ -30,7 +30,7 @@ Clustericious::HelloWorld - Clustericious hello world application
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 SYNOPSIS
 
