@@ -9,7 +9,7 @@ use File::ReadBackwards;
 use Clustericious;
 
 # ABSTRACT: A Log::Log4perl wrapper for use with Clustericious.
-our $VERSION = '1.10'; # VERSION
+our $VERSION = '1.11'; # VERSION
 
 
 sub import {
@@ -34,8 +34,6 @@ sub init_logging {
     $Log::Log4perl::Logger::INITIALIZED = 0 if $initPid && $initPid != $$;
     $initPid = $$;
 
-    my @Confdirs = Clustericious->_config_path;
-
     # Logging
     $ENV{LOG_LEVEL} ||= 'WARN';
 
@@ -43,7 +41,7 @@ sub init_logging {
     my $l4p_pat; # pattern for screen logging
     my $l4p_file; # file (global or app specific)
 
-    $l4p_dir  = first { -d $_ && (-e "$_/log4perl.conf" || -e "$_/$app_name.log4perl.conf") } @Confdirs;
+    $l4p_dir  = first { -d $_ && (-e "$_/log4perl.conf" || -e "$_/$app_name.log4perl.conf") } Clustericious->_config_path;
     $l4p_pat  = "[%d] [%Z %H %P] %5p: %m%n";
     if ($l4p_dir) {
         $l4p_file = first {-e "$l4p_dir/$_"} ("$app_name.log4perl.conf", "log4perl.conf");
@@ -112,7 +110,7 @@ Clustericious::Log - A Log::Log4perl wrapper for use with Clustericious.
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 SYNOPSIS
 
