@@ -6,11 +6,10 @@ use 5.010;
 use Mojo::Base 'Mojolicious::Plugin';
 use File::Basename ();
 use Sys::Hostname ();
-use List::Util qw/ uniq /;
+use List::MoreUtils ();
 
 # ABSTRACT: Routes common to all clustericious applications
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.11'; # VERSION
 
 
 sub register
@@ -124,7 +123,7 @@ sub _dump_api {
       push @all, $class->_dump_api($app, $r->children);
     }
   }
-  return uniq sort @all;
+  return List::MoreUtils::uniq sort @all;
 }
 
 sub _dump_api_table_types
@@ -178,7 +177,7 @@ Clustericious::Plugin::CommonRoutes - Routes common to all clustericious applica
 
 =head1 VERSION
 
-version 1.28_01
+version 1.11
 
 =head1 SYNOPSIS
 
@@ -266,8 +265,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
