@@ -5,11 +5,10 @@ use warnings;
 use Clustericious::Log;
 use Mojo::ByteStream qw/b/;
 use Mojo::URL;
-use Clustericious::Config;
 use Mojo::Base 'Mojolicious::Plugin';
 
 # ABSTRACT: Plugin for clustericious to use PlugAuth.
-our $VERSION = '1.10'; # VERSION
+our $VERSION = '1.11'; # VERSION
 
 
 has 'config_url';
@@ -34,7 +33,7 @@ sub authenticate {
     # Everyone needs to send an authorization header
     my $auth = $c->req->headers->authorization or do {
         $c->res->headers->www_authenticate(qq[Basic realm="$realm"]);
-        $c->render_text("auth required", layout => "", status => 401);
+        $c->render(text => "auth required", layout => "", status => 401);
         return;
     };
 
@@ -164,29 +163,21 @@ Clustericious::Plugin::PlugAuth - Plugin for clustericious to use PlugAuth.
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 SYNOPSIS
 
 MyApp.conf:
 
- {"plug_auth":{"url":"http://plugauthserver:3000"}}
+ ---
+ plug_auth:
+   url: http://plugauthserver:3000
 
 Application:
 
  package MyApp;
  
  use base qw( Clustericious::App );
- 
- sub startup {
-   my $self = shift;
-   $self->SUPER::startup(@_);
-   # done by default for all clustericious applications.
-   #$self->plugin('plug_auth');
- }
- 
- package MyApp::Routes;
- 
  use Clustericious::RouteBuilder;
 
  # unprotected 
