@@ -2,11 +2,14 @@ package Clustericious::RouteBuilder::Proxy;
 
 use strict;
 use warnings;
+use Carp qw( carp );
 
 # ABSTRACT: build proxy routes easily
-our $VERSION = '1.10'; # VERSION
+our $VERSION = '1.11'; # VERSION
 
 
+carp "Clustericious::RouteBuilder::Proxy is deprecated, consider using Mojolicious::Plugin::Proxy instead";
+
 use Sub::Exporter -setup => {
     exports => [
         "proxy" => \&_build_proxy,
@@ -50,9 +53,6 @@ sub _build_proxy {
         #LOGDIE "recursive proxy " if $self->req->url->to_abs eq $url->to_abs;
 
         my $remote = $self->tx->remote_address;
-        #TRACE "proxying (from $remote) " . $self->req->method . ' ' .
-        #      _sanitize_url($self->req->url->to_abs) . " to " .
-        #      _sanitize_url($url->to_abs);
 
         my $tx = Mojo::Transaction::HTTP->new;
         my $req = $tx->req;
@@ -94,16 +94,6 @@ sub _build_proxy_service {
     }
 }
 
-sub _sanitize_url {
-    # Remove passwords from urls for displaying
-    my $url = shift;
-    $url = Mojo::URL->new($url) unless ref $url eq "Mojo::URL";
-    return $url unless $url->userinfo;
-    my $c = $url->clone;
-    $c->userinfo("user:*****");
-    return $c;
-}
-
 1;
 
 __END__
@@ -118,7 +108,7 @@ Clustericious::RouteBuilder::Proxy - build proxy routes easily
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 SYNOPSIS
 
