@@ -30,7 +30,7 @@ sub _init
 BEGIN { _init() }
 
 # ABSTRACT: Test Clustericious::Config
-our $VERSION = '1.10'; # VERSION
+our $VERSION = '1.11'; # VERSION
 
 
 sub create_config_ok ($;$$)
@@ -149,7 +149,7 @@ Test::Clustericious::Config - Test Clustericious::Config
 
 =head1 VERSION
 
-version 1.10
+version 1.11
 
 =head1 SYNOPSIS
 
@@ -207,7 +207,10 @@ that you use in your test after C<use strict> and C<use warnings>).
 
 =head1 FUNCTIONS
 
-=head2 create_config_ok $name, $config, [$test_name]
+=head2 create_config_ok
+
+  create_config_ok $name, $config;
+  create_config_ok $name, $config, $test_name;
 
 Create a Clustericious config with the given C<$name>.
 If C<$config> is a reference then it will create the 
@@ -238,19 +241,28 @@ In addition to being a test that will produce a ok/not ok
 result as output, this function will return the full path
 to the configuration file created.
 
-=head2 create_directory_ok $path, [$test_name]
+=head2 create_directory_ok
+
+ create_directory_ok $path;
+ create_directory_ok $path, $test_name;
 
 Creates a directory in your test environment home directory.
 This directory will be recursively removed when your test
 terminates.  This function returns the full path of the 
 directory created.
 
-=head2 home_directory_ok [$test_name]
+=head2 home_directory_ok
+
+ home_directory_ok;
+ home_directory_ok $test_name;
 
 Tests that the temp home directory has been created okay.
 Returns the full path of the home directory.
 
-=head2 create_config_helper_ok $helper_name, $helper_coderef, [ $test_name ]
+=head2 create_config_helper_ok
+
+ create_config_helper_ok $helper_name, $helper_coderef;
+ create_config_helper_ok $helper_name, $helper_coderef, $test_name;
 
 Install a helper which can be called from within a configuration template.
 Example:
